@@ -1,9 +1,10 @@
+package Perl::Critic::Lokku;
+$Perl::Critic::Lokku::VERSION = '0.002';
 use strict;
 use warnings;
 use utf8;
-package Perl::Critic::Lokku;
 # ABSTRACT: A collection of Perl::Critic policies from Lokku
-$Perl::Critic::Lokku::VERSION = '0.001';
+
 1;
 
 __END__
@@ -18,7 +19,7 @@ Perl::Critic::Lokku - A collection of Perl::Critic policies from Lokku
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -34,10 +35,10 @@ about L<Try::Tiny>.
 
 =head3 L<Perl::Critic::Policy::TryTiny::RequireCatch>
 
-Did you know that C< try { ... } finally { ... }> suppresse all errors? This
+Did you know that C< try { ... } finally { ... }> suppresses all errors? This
 policy will require you to include a C<catch> block, even if it's only empty.
 
-=head3 L<Perl::Critic::Policy::TryTiny::ProhibitExitSubroutine>
+=head3 L<Perl::Critic::Policy::TryTiny::ProhibitExitingSubroutine>
 
 Did you know that C<next> inside a C<try> block will exit that block, not the
 surrounding loop? This policy will require you use a label at least, and that
@@ -54,7 +55,7 @@ David D Lowe <flimm@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Lokku <cpan@lokku.com>.
+This software is copyright (c) 2015 by Lokku <cpan@lokku.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
